import { join } from '#p/util/path.js';
import { hasDependency, load } from '#p/util/plugin.js';
import ts from 'typescript';
const title = 'Metro';
const enablers = ['@react-native/metro-config'];
const isEnabled = ({ dependencies }) => hasDependency(dependencies, enablers);
const getModuleResolvers = async (dir) => {
    try {
        const { __KNIP_PLATFORMS__ } = await load(join(dir, 'metro.config.js'));
        const createModuleResolver = (dirs, extensions) => (id, containingFile, compilerOptions, sys, resolve) => {
            for (const dir of dirs) {
                for (const ext of extensions) {
                    const mod = resolve(id + dir + ext, containingFile, compilerOptions, sys).resolvedModule;
                    if (mod)
                        return mod;
                }
            }
        };
        const moduleResolvers = {};
        for (const [key, config] of Object.entries(__KNIP_PLATFORMS__)) {
            const [dirs, extensions] = config;
            moduleResolvers[key] = createModuleResolver(dirs, extensions);
        }
        return moduleResolvers;
    }
    catch {
        return {};
    }
};
const entry = ['metro.config.js', 'react-native.config.js'];
export default {
    title,
    enablers,
    isEnabled,
    getModuleResolvers,
    entry,
};
